@@ -1221,7 +1221,9 @@ class DataHandler:
         A = np.zeros([self.edge_roi_image_flat.shape[0], len(self.rois)], dtype=int)
         for num, roi in enumerate(self.rois):
             A[roi, num] = 1
-        rval, significant_samples = classify_components_ep(self.dataset_trials_filtered_loaded, A, np.vstack([self.get_time_trace(x+1) for x in range(len(self.rois))]))
+        rval, significant_samples = classify_components_ep(
+            self.dataset_trials_filtered_loaded, A,
+            np.vstack([self.get_time_trace(x + 1) for x in range(len(self.rois))]))
         pass
 
     def export(self):
@@ -1231,7 +1233,7 @@ class DataHandler:
                 self.time_trace_params["denoise"] = denoise
                 self.time_trace_params["time_trace_type"] = time_type
                 self.calculate_time_traces()
-                if time_type=="Mean" and denoise:
+                if time_type == "Mean" and denoise:
                     self.calculate_statistics()
         self.time_trace_params["time_trace_type"] = temp_type
         self.save_rois(self.rois)
@@ -1256,12 +1258,15 @@ class DataHandler:
             [self.edge_roi_image_flat,
              np.zeros(shape),
              np.zeros(shape)])
-        max_image = np.reshape(np.max([self.max_images[x] for x in self._trials_loaded_indices],axis=0),(-1,1))
-        roi_image_blob_w_background =roi_image_blob+np.hstack(
-                [max_image, max_image,max_image])/max_image.max()*255
-        roi_image_outline_w_background = roi_image_outline +np.hstack(
-                [max_image, max_image,max_image])/max_image.max()*255
-        self.save_image(roi_image_blob, os.path.join(self.save_dir_path, "roi_blob.png"))
+        max_image = np.reshape(
+            np.max([self.max_images[x] for x in self._trials_loaded_indices], axis=0),
+            (-1, 1))
+        roi_image_blob_w_background = roi_image_blob + np.hstack(
+            [max_image, max_image, max_image]) / max_image.max() * 255
+        roi_image_outline_w_background = roi_image_outline + np.hstack(
+            [max_image, max_image, max_image]) / max_image.max() * 255
+        self.save_image(roi_image_blob,
+                        os.path.join(self.save_dir_path, "roi_blob.png"))
         self.save_image(roi_image_outline,
                         os.path.join(self.save_dir_path, "roi_outline.png"))
         self.save_image(roi_image_outline_w_background,
@@ -1269,14 +1274,14 @@ class DataHandler:
         self.save_image(roi_image_blob_w_background,
                         os.path.join(self.save_dir_path, "roi_blob_background.png"))
         self.save_image(np.hstack(
-                [max_image, max_image,max_image]),
-                        os.path.join(self.save_dir_path, "max.png"))
+            [max_image, max_image, max_image]),
+            os.path.join(self.save_dir_path, "max.png"))
 
     def save_image(self, image, path):
         img = Image.fromarray(
             (np.reshape(image - image.min(),
                         (self.shape[0], self.shape[1], 3)) / (
-                         image.max() - image.min()) * 255).astype("uint8"))
+                     image.max() - image.min()) * 255).astype("uint8"))
         img.save(path)
     def delete_roi_vars(self):
         self.rois = []
