@@ -14,10 +14,10 @@ logger1 = logging.getLogger("CIDAN.ImageView.ROIImageViewModule")
 class ROIImageViewModule(ImageViewModule):
     # QApplication.mouseButtons() == Qt.LeftButton
     def __init__(self, main_widget, tab, settings_tab=True):
-        super(ROIImageViewModule, self).__init__(main_widget, histogram=True)
+        super(ROIImageViewModule, self).__init__(main_widget, histogram=False)
         self.tab = tab
         self.resetting_view = False  # Way to prevent infinite loops of reset_view
-        self.current_foreground_intensity = 80
+        self.current_foreground_intensity = 30
         self.click_event = False
         self.outlines = True
         self.trial_selector_input = OptionInput(
@@ -39,6 +39,7 @@ class ROIImageViewModule(ImageViewModule):
         if settings_tab:
             self.layout.removeWidget(self.image_view)
             self.layout.addWidget(self.createTabLayout())
+
     def createSettings(self):
         self.display_settings_layout = QVBoxLayout()
 
@@ -86,7 +87,7 @@ class ROIImageViewModule(ImageViewModule):
         label_10 = QLabel("10")
         label_10.setStyleSheet("QWidget {border: 0px solid #32414B;}")
         background_slider_layout.addWidget(label_10)
-        label_overlay = QLabel("Change overlay intensity:")
+        label_overlay = QLabel("Change background intensity:")
         label_overlay.setStyleSheet("QWidget {border: 0px solid #32414B;}")
         self.display_settings_layout.addWidget(label_overlay)
         self.display_settings_layout.addLayout(background_slider_layout)
@@ -96,7 +97,7 @@ class ROIImageViewModule(ImageViewModule):
         roi_view_tabs = QTabWidget()
         roi_view_tabs.setStyleSheet("QTabWidget {font-size: 20px;}")
         # Display settings tab
-        display_settings =self.createSettings()
+        display_settings = self.createSettings()
 
         # ROI image view part
         self.setStyleSheet(
@@ -115,14 +116,14 @@ class ROIImageViewModule(ImageViewModule):
         return self.display_settings_layout
 
     def intensitySliderChanged(self):
-        self.current_foreground_intensity = 10 - (
+        self.current_foreground_intensity = (
                 float(self.background_slider.value()) / 10)
 
         self.updateImageDisplay()
 
     def set_background(self, name, func_name, update_image=True, reset_override=False):
         if (not self.resetting_view or reset_override):
-
+            self.main_widget.console.updateText("Setting current background to: %s"%func_name)
             # Background refers to the image behind the rois
             shape = self.main_widget.data_handler.shape
             if func_name == "Mean Image":
@@ -131,14 +132,17 @@ class ROIImageViewModule(ImageViewModule):
                         self.data_handler.trials_loaded.index(
                             self.trial_selector_input.current_state())][:].reshape(
                     [-1, 1])
+                self.current_background_name = "Mean Image"
             elif func_name == "Max Image":
                 self.current_background = self.main_widget.data_handler.max_images[
                                               self.data_handler.trials_loaded.index(
                                                   self.trial_selector_input.current_state())][
                                           :].reshape(
                     [-1, 1])
+                self.current_background_name = "Max Image"
             elif func_name == "Blank Image":
                 self.current_background = np.zeros([shape[0] * shape[1], 1])
+                self.current_background_name = "Blank Image"
             # if func_name == "Temporal Correlation Image":
             #     self.current_background = self.data_handler.temporal_correlation_image.reshape(
             #         [-1, 1])
@@ -146,8 +150,11 @@ class ROIImageViewModule(ImageViewModule):
                 try:
                     self.current_background = self.data_handler.eigen_norm_image.reshape(
                         [-1, 1])
+                    self.current_background_name = "Eigen Norm Image"
                 except AttributeError:
                     print("Eigen vectors aren't currently generated or valid")
+                    self.main_widget.console.updateText("Can't display EigenNorm image, Eigen vectors aren't currently generated or valid")
+
                     self.current_background = self.main_widget.data_handler.max_images[
                                                   self.data_handler.trials_loaded.index(
                                                       self.trial_selector_input.current_state())][
@@ -156,12 +163,22 @@ class ROIImageViewModule(ImageViewModule):
                     self.current_background_name = "Max Image"
             else:
                 self.current_background_name = "Max Image"
-                self.trial_selector_input.set_default_val()
-                self.current_background = self.main_widget.data_handler.max_images[
+                try:
+                    self.trial_selector_input.set_default_val()
+
+                    self.current_background = self.main_widget.data_handler.max_images[
                                               self.data_handler.trials_loaded.index(
                                                   self.trial_selector_input.current_state())][
                                           :].reshape(
-                    [-1, 1])
+                        [-1, 1])
+                except AttributeError:
+                    pass
+            try:
+                if self.current_background_name != self.background_chooser.current_state():
+                    # pass
+                    self.background_chooser.set_val(self.current_background_name)
+            except AttributeError:
+                pass
             if update_image:
                 self.updateImageDisplay()
 
@@ -190,8 +207,9 @@ class ROIImageViewModule(ImageViewModule):
             shape = self.main_widget.data_handler.shape
             # range_list = self.main_widget.roi_image_view.image_view.view.viewRange()
             background_max = self.current_background.max()
-            background_image_scaled = (self.current_foreground_intensity * 255 / (
-                background_max if background_max != 0 else 1)) * self.current_background
+            background_min= self.current_background.min()
+            background_image_scaled = (self.current_foreground_intensity*(self.current_background-background_min) * 235 / (
+                (background_max-background_min) if (background_max-background_min) != 0 else 1))
             background_image_scaled_3_channel = np.hstack(
                 [background_image_scaled, background_image_scaled,
                  background_image_scaled])
@@ -199,7 +217,8 @@ class ROIImageViewModule(ImageViewModule):
                                    "edge_roi_image_flat"):
                 self.image_item.image = background_image_scaled_3_channel.reshape(
                     (shape[0], shape[1], 3))
-                self.image_item.updateImage(autoLevels=True)
+                self.image_item.updateImage(autoLevels=False)
+                self.image_item.ui.histogram.setHistogramRange(0, 255)
             elif new:
                 # if self.add_image:
                 combined = self.roi_image_flat + background_image_scaled_3_channel + self.select_image_flat
@@ -213,7 +232,9 @@ class ROIImageViewModule(ImageViewModule):
             else:
                 self.image_item.image = background_image_scaled_3_channel.reshape(
                     (shape[0], shape[1], 3))
-                self.image_item.updateImage(autoLevels=True)
+                self.image_item.updateImage(autoLevels=False)
+                self.image_item.ui.histogram.setHistogramRange(0, 255)
+
 
                 # if self.add_image:
                 combined = (self.roi_image_flat + self.select_image_flat).reshape(
@@ -246,9 +267,12 @@ class ROIImageViewModule(ImageViewModule):
         except AttributeError:
             pass
         except IndexError:
+            self.main_widget.console.updateText("Please regenerate ROIs before trying this operation")
+
             print("Please regenerate ROIs before trying this operation")
         except ValueError as e:
             if "shape" in e.args[0]:
+                self.main_widget.console.updateText("Error please try again")
                 print("Error please try again")
                 self.reset_view()
 
@@ -266,6 +290,7 @@ class ROIImageViewModule(ImageViewModule):
             self.updateImageDisplay()
         except ValueError as e:
             if "shape" in e.args[0]:
+                self.main_widget.console.updateText("Error please try again")
                 print("Error please try again")
                 self.reset_view()
 
