@@ -138,9 +138,12 @@ class ROIPaintImageViewModule(ROIImageViewModule):
             shape = self.main_widget.data_handler.shape
 
             # range_list = self.main_widget.roi_image_view.image_view.view.viewRange()
-            background_max = self.current_background.max()
-            background_image_scaled = (self.current_foreground_intensity * 255 / (
-                background_max if background_max != 0 else 1)) * self.current_background
+            background_max = np.percentile(self.current_background, 98)
+            background_min = np.percentile(self.current_background, 2)
+            background_image_scaled = (self.current_foreground_intensity/10 * (
+                        self.current_background - background_min) * 235 / (
+                                           (background_max - background_min) if (
+                                                                                            background_max - background_min) != 0 else 1))
             background_image_scaled_3_channel = np.hstack(
                 [background_image_scaled, background_image_scaled,
                  background_image_scaled])
@@ -148,7 +151,8 @@ class ROIPaintImageViewModule(ROIImageViewModule):
                                    "edge_roi_image_flat"):
                 self.image_item.image = background_image_scaled_3_channel.reshape(
                     (shape[0], shape[1], 3))
-                self.image_item.updateImage(autoLevels=True)
+                self.image_item.updateImage(autoLevels=False)
+                self.image_item.setLevels((0, 255))
             elif new:
                 # if self.add_image:
                 combined = self.roi_image_flat + background_image_scaled_3_channel + self.select_image_flat
@@ -159,11 +163,14 @@ class ROIPaintImageViewModule(ROIImageViewModule):
                 #     combined[mask] = self.roi_image_flat[mask]
                 combined_reshaped = combined.reshape((shape[0], shape[1], 3))
                 self.tab.image_view.setImage(combined_reshaped)
+
                 self.clearPixelSelection(update_display=False)
+                self.image_item.setLevels((0, 255))
             else:
                 self.image_item.image = background_image_scaled_3_channel.reshape(
                     (shape[0], shape[1], 3))
-                self.image_item.updateImage(autoLevels=True)
+                self.image_item.updateImage(autoLevels=False)
+                self.image_item.setLevels((0, 255))
 
                 # if self.add_image:
                 combined = (self.roi_image_flat + self.select_image_flat).reshape(
@@ -200,6 +207,7 @@ class ROIPaintImageViewModule(ROIImageViewModule):
         self.current_selected_pixels_list = []
         if update_display:
             self.updateImageDisplay()
+        self.main_widget.console.updateText("Clearing currently selected pixels")
 
     def check_pos_in_image(self, x, y):
         pass
