@@ -1,6 +1,7 @@
 import os
 
 from PySide2.QtCore import QThreadPool
+from qtpy import QtGui
 
 from CIDAN.GUI.Tabs.AnalysisTab import AnalysisTab
 
@@ -32,17 +33,26 @@ class MainWindow(QMainWindow):
     def __init__(self, dev=False, preload=False):
         super().__init__()
         self.title = 'CIDAN'
-        self.width = 900
-        self.height = 800
+        scale = (self.logicalDpiX() / 96.0-1)/2+1
+        sizeObject = QtGui.QGuiApplication.primaryScreen().availableGeometry()
+
+
+        self.width = 1200 * scale
+        self.height = 1066.6 * scale
+        if self.height > sizeObject.height() * .90:
+            self.height = sizeObject.height() * .90
+        if self.width > sizeObject.width() * .95:
+            self.width = sizeObject.width() * .95
         self.setWindowTitle(self.title)
         self.setMinimumSize(self.width, self.height)
         self.main_menu = self.menuBar()
+        self.setContentsMargins(0,0,0,0)
         self.table_widget = MainWidget(self, dev=dev, preload=preload)
         self.setCentralWidget(self.table_widget)
         # self.setStyleSheet(qdarkstyle.load_stylesheet())
-        style = """
-            QWidget {font-size: 15px;}
-            QTabWidget {font-size: 15px; padding:1px; margin:5px;}
+        style = str("""
+            QWidget {font-size: %dpx;}
+            QTabWidget {font-size: %dpx; padding:0px; margin:%dpx;}
             QTabBar::tab {
                 background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,
                                            stop: 0 #E1E1E1, stop: 0.4 #DDDDDD,
@@ -51,15 +61,16 @@ class MainWindow(QMainWindow):
                 /*border-bottom-color: #C2C7CB; !* same as the pane color *!*/
                 
                 min-width: 8ex;
-                padding:1px;
-                border:1px;
+                padding:%dpx;
+                border:%dpx;
             }
             
             QComboBox::item:checked {
               font-weight: bold;
-              height: 12px;
+              height: %dpx;
             }
-            """
+            """ % (
+            25 * scale, 25 * scale, 0 * scale, 0* scale, 0 * scale, 25 * scale))
         self.setStyleSheet(qdarkstyle.load_stylesheet() + style)
 
         # extractAction.triggered.connect()
@@ -103,12 +114,14 @@ class MainWidget(QWidget):
         parent
         """
         super().__init__(parent)
+        self.scale = (self.logicalDpiX() / 96.0-1)/2+1
         self.main_window = parent
         self.threadpool = QThreadPool()
         self.main_menu = self.main_window.main_menu
         self.layout = QVBoxLayout(self)
         self.data_handler = None
         self.thread_list = []
+        self.setContentsMargins(0,0,0,0)
 
         self.dev = dev
         self.tab_widget = QTabWidget()
@@ -122,10 +135,10 @@ class MainWidget(QWidget):
             self.tab_widget.setTabEnabled(num + 1, False)
         self.layout.addWidget(self.tab_widget)
         #
-        # self.console = ConsoleWidget()
+        self.console = ConsoleWidget()
         # self.console.setMaximumHeight(150)
         # self.console.setMinimumHeight(150)
-        # self.layout.addWidget(self.console)
+        self.layout.addWidget(self.console)
         self.setLayout(self.layout)
 
         # Initialize top bar menu
@@ -267,9 +280,11 @@ if __name__ == "__main__":
     logging.basicConfig(filename=LOG_FILENAME, level=logging.DEBUG)
     logger = logging.getLogger("CIDAN")
     logger.debug("Program started")
-    QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)  # enable highdpi scaling
+    QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling,
+                              True)  # enable highdpi scaling
     QApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)  # use highdpi icons
     app = QApplication([])
+
     app.setApplicationName("CIDAN")
     widget = MainWindow(dev=True, preload=True)
 
