@@ -36,8 +36,7 @@ class FileOpenTab(Tab):
             lambda: load_new_dataset(main_widget, dataset_file_input.current_state(),
                                      save_dir_new_file.current_state(),
                                      load_into_mem=self.folder_load_into_mem.current_state()))
-        self.file_load_into_mem = BoolInput("Load data into memory(not recomended "
-                                            "for large datasets)", "", None, False,
+        self.file_load_into_mem = BoolInput("Load data into memory", "", None, True,
                                             "")
         folder_open_button = QPushButton()
         folder_open_button.setContentsMargins(0, 0, 0, 11)
@@ -50,8 +49,7 @@ class FileOpenTab(Tab):
                                      load_into_mem=self.folder_load_into_mem.current_state()))
         self.folder_open_single_trial = BoolInput("Open folder as single trial", "",
                                                   None, False, "")
-        self.folder_load_into_mem = BoolInput("Load data into memory(not recomended "
-                                              "for large datasets)", "", None, False,
+        self.folder_load_into_mem = BoolInput("Load data into memory", "", None, True,
                                               "")
         prev_session_open_button = QPushButton()
         prev_session_open_button.setContentsMargins(0, 0, 0, 11)
