@@ -44,7 +44,7 @@ class ROIExtractionTab(Tab):
 
         # This part creates the top left settings/roi list view in two tabs
         self.tab_selector_roi = QTabWidget()
-        self.tab_selector_roi.setStyleSheet("QTabWidget {font-size: 20px;}")
+        # self.tab_selector_roi.setStyleSheet("QTabWidget {font-size: 20px;}")
 
         # ROI modification Tab
         roi_modification_tab = QWidget()
@@ -54,7 +54,7 @@ class ROIExtractionTab(Tab):
 
         roi_modification_tab_layout.setContentsMargins(2, 2, 2, 2)
         roi_modification_tab_layout_top = QHBoxLayout()
-        roi_modification_tab_layout_top.setContentsMargins(0,0,0,0)
+        roi_modification_tab_layout_top.setContentsMargins(0, 0, 0, 0)
         roi_modification_tab_layout.addLayout(roi_modification_tab_layout_top)
         display_settings = self.image_view.createSettings()
         display_settings.setStyleSheet("QWidget {border: 2px solid #32414B;}")
@@ -70,13 +70,13 @@ class ROIExtractionTab(Tab):
         roi_modification_button_top_widget.setLayout(roi_modification_button_top_layout)
         # roi_modification_tab_layout.addLayout(roi_modification_button_top_layout)
 
-        add_new_roi = QPushButton(text="New ROI from Selection")
+        add_new_roi = QPushButton(text="Create ROI from\nSelection")
         add_new_roi.clicked.connect(lambda x: self.add_new_roi())
         add_to_roi = QPushButton(text="Add to Selected ROI")
         add_to_roi.clicked.connect(
             lambda x: self.modify_roi(self.roi_list_module.current_selected_roi, "add"))
 
-        sub_to_roi = QPushButton(text="Subtract from Selected ROI")
+        sub_to_roi = QPushButton(text="Subtract from\nSelected ROI")
         sub_to_roi.clicked.connect(
             lambda x: self.modify_roi(self.roi_list_module.current_selected_roi,
                                       "subtract"))
@@ -120,7 +120,7 @@ class ROIExtractionTab(Tab):
 
         painter_layout = QVBoxLayout()
         painter_widget.setLayout(painter_layout)
-        label =QLabel(text="Selector Brush: ")
+        label = QLabel(text="Selector Brush: ")
         label.setStyleSheet("QWidget {border: 0px solid #32414B;}")
         painter_layout.addWidget(label)
 
@@ -129,7 +129,6 @@ class ROIExtractionTab(Tab):
         painter_layout.addWidget(sub_button)
         painter_layout.addWidget(magic_wand)
 
-
         self._brush_size_options = OptionInput("Brush Size:", "",
                                                lambda x,
                                                       y: self.image_view.setBrushSize(
@@ -145,7 +144,9 @@ class ROIExtractionTab(Tab):
         clear_from_selection.clicked.connect(
             lambda x: self.image_view.clearPixelSelection())
         painter_layout.addWidget(clear_from_selection)
-        roi_modification_button_top_widget.setStyleSheet("QWidget {border: 2px solid #32414B; font-size: 14px}")
+        roi_modification_button_top_widget.setStyleSheet(
+            "QWidget {border: 2px solid #32414B; font-size: %dpx}" % (
+                    self.main_widget.scale * 20))
         painter_widget.setStyleSheet("QWidget {border: 2px solid #32414B;}")
         roi_modification_tab_layout_top.addWidget(roi_modification_button_top_widget)
         roi_modification_tab_layout_top.addWidget(painter_widget)
@@ -169,8 +170,8 @@ class ROIExtractionTab(Tab):
         # adding the tabs to the window
         self.tab_selector_roi.addTab(self.roi_settings, "ROI Creation")
         self.tab_selector_roi.addTab(roi_modification_tab, "ROI Modification")
-        self.tab_selector_roi.setMaximumWidth(435)
-        self.tab_selector_roi.setMinimumWidth(435)
+        # self.tab_selector_roi.setMaximumWidth(435)
+        # self.tab_selector_roi.setMinimumWidth(435)
         # Eigen vector viewer if dev mode is enabled
         if self.main_widget.dev:
             self.eigen_view = QWidget()
@@ -194,7 +195,7 @@ class ROIExtractionTab(Tab):
 
         # Tab selector for the time trace window
         tab_selector_time_trace = QTabWidget()
-        tab_selector_time_trace.setStyleSheet("QTabWidget {font-size: 20px;}")
+        # tab_selector_time_trace.setStyleSheet("QTabWidget {font-size: 20px;}")
         tab_selector_time_trace.setMaximumHeight(220)
         # plot of time traces
         self.time_plot = pg.PlotWidget()
@@ -235,7 +236,7 @@ class ROIExtractionTab(Tab):
         super().__init__("ROI Extraction",
                          column_1=[self.tab_selector_roi],
                          column_2=[self.image_view, tab_selector_time_trace],
-                         column_2_display=True)
+                         column_2_display=True, horiz_moveable=True)
 
     @property
     def data_handler(self):
@@ -245,9 +246,11 @@ class ROIExtractionTab(Tab):
         """
         Adds a new roi using selection(self.image_view.current_selected_pixels_list)
         """
+        self.main_widget.console.updateText("Creating new ROI")
         if (self.main_widget.checkThreadRunning()):
             if len(self.image_view.current_selected_pixels_list) == 0:
                 print("Please select some pixels")
+                self.main_widget.console.updateText("Please select some pixels")
                 return
             self.data_handler.rois.append(
                 np.array(self.image_view.current_selected_pixels_list))
@@ -278,6 +281,7 @@ class ROIExtractionTab(Tab):
         if (self.main_widget.checkThreadRunning()):
             roi_num = roi_num - 1
             try:
+                self.main_widget.console.updateText("Deleting ROI #%d"%roi_num+1)
                 self.data_handler.rois.pop(roi_num)
                 self.data_handler.gen_roi_display_variables()
                 self.data_handler.time_traces.pop(roi_num)
@@ -286,6 +290,7 @@ class ROIExtractionTab(Tab):
                 self.deselectRoiTime()
                 self.main_widget.tabs[2].updateTab()
             except IndexError:
+                self.main_widget.console.updateText("Invalid ROI Selected")
                 print("Invalid ROI Selected")
 
     def modify_roi(self, roi_num, add_subtract="add"):
@@ -303,19 +308,23 @@ class ROIExtractionTab(Tab):
         if (self.main_widget.checkThreadRunning()):
             if roi_num is None:
                 print("Please select an roi")
+                self.main_widget.console.updateText("Please Select an ROI")
                 return False
             roi_num = roi_num - 1
             if len(self.image_view.current_selected_pixels_list) == 0:
                 print("Please select some pixels")
+                self.main_widget.console.updateText("Please select some pixels")
                 return False
             if add_subtract == "add":
                 print("Adding Selection to ROI #" + str(roi_num + 1))
+
                 self.data_handler.rois[roi_num] = combine_rois(
                     self.data_handler.rois[roi_num],
                     self.image_view.current_selected_pixels_list)
                 self.data_handler.gen_roi_display_variables()
                 self.data_handler.calculate_time_trace(roi_num)
 
+
             if add_subtract == "subtract":
                 print("Subtracting Selection from ROI #" + str(roi_num + 1))
                 self.data_handler.rois[roi_num] = [x for x in
@@ -325,10 +334,15 @@ class ROIExtractionTab(Tab):
                 self.data_handler.gen_roi_display_variables()
                 self.data_handler.calculate_time_trace(roi_num)
             self.deselectRoiTime()
-            self.roi_list_module.set_current_select(roi_num+1)
+            self.roi_list_module.set_current_select(roi_num + 1)
             self.image_view.clearPixelSelection()
             self.update_roi(new=False)
+            if add_subtract=="subtract":
+                self.main_widget.console.updateText("Subtracting Selection from ROI #" + str(roi_num + 1))
 
+            if add_subtract=="add":
+                self.main_widget.console.updateText(
+                    "Adding Selection to ROI #" + str(roi_num + 1))
             return True
 
     def update_roi(self, new=True):
